<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://#
 * @since      1.0.0
 *
 * @package    Solar_Calculator
 * @subpackage Solar_Calculator/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Solar_Calculator
 * @subpackage Solar_Calculator/public
 * @author     jaysis<hello@jaysis.ai>
 */
class Solar_Calculator_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Solar_Calculator_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Solar_Calculator_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( 'bootstrap', plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'solar-calculator-public', plugin_dir_url( __FILE__ ) . 'css/solar-calculator-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'solar-calculator-model', plugin_dir_url( __FILE__ ) . 'css/solar-calculator-model.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'ion.rangeSlider', plugin_dir_url( __FILE__ ) . 'css/ion.rangeSlider.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'ion.rangeSlider.skinModern', plugin_dir_url( __FILE__ ) . 'css/ion.rangeSlider.skinModern.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Solar_Calculator_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Solar_Calculator_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( 'jQuery-sc', 'https://ajax.googleapis.com/ajax/libs/jquery/3.6.1/jquery.min.js', array(), null, false);
		wp_enqueue_script( 'solar-calculator-bootstrap', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array(), $this->version, false );
		wp_enqueue_script( 'solar-calculator-script', plugin_dir_url( __FILE__ ) . 'js/solar-calculator-script.js', array(), $this->version, false );
		wp_enqueue_script( 'solar-calculator-model-js', plugin_dir_url( __FILE__ ) . 'js/solar-calculator-model.js', array(), $this->version, false );
		wp_enqueue_script( 'solar-calculator-public-js', plugin_dir_url( __FILE__ ) . 'js/solar-calculator-public.js', array(), $this->version, false );
		wp_enqueue_script( 'general-scjs', plugin_dir_url( __FILE__ ) . 'js/general.js', array(), $this->version, false );
		wp_enqueue_script( 'custom-scal', plugin_dir_url( __FILE__ ) . 'js/custom.js', array(), $this->version, false );

	}

	public function init_scripts(){
		// wp_enqueue_script( 'custom-sc', plugin_dir_url( __FILE__ ) . 'js/custom.js', array(), $this->version, false );
	}

	public function solar_calculator_shortcode_callback() {
		ob_start();
		include(plugin_dir_path( dirname( __FILE__ ) ) . 'public/templates/sc-template.php');
		return ob_get_clean();
	}

}
