<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://#
 * @since             1.0.0
 * @package           Solar_Calculator
 *
 * @wordpress-plugin
 * Plugin Name:       Solar Calculator
 * Plugin URI:        https://#
 * Description:       Here is a solar calculator plugin to calculate solar and EMI cost.
 * Version:           1.0.0
 * Author:            jaysis
 * Author URI:        https://#
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       solar-calculator
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'SOLAR_CALCULATOR_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-solar-calculator-activator.php
 */
function activate_solar_calculator() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-solar-calculator-activator.php';
	Solar_Calculator_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-solar-calculator-deactivator.php
 */
function deactivate_solar_calculator() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-solar-calculator-deactivator.php';
	Solar_Calculator_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_solar_calculator' );
register_deactivation_hook( __FILE__, 'deactivate_solar_calculator' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-solar-calculator.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_solar_calculator() {

	$plugin = new Solar_Calculator();
	$plugin->run();

}
run_solar_calculator();
